@@ -30,6 +30,7 @@
 
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 #include <libgnomevfs/gnome-vfs-method.h>
 #include <libgnomevfs/gnome-vfs-module.h>
@@ -143,7 +144,6 @@ struct _SmbDirHandle {
 	gboolean is_files;
 	char *server;
 	GList *contents;
-	const GnomeVFSDirectoryFilter *filter;
 };
 
 /* Global vars: */
@@ -157,8 +157,8 @@ extern pstring global_myname;
 static GHashTable *virtual_hash = NULL;
 static GHashTable *server_auth_infos = NULL;
 
-#undef DEBUG_SMB_ENABLE
-#undef DEBUG_SMB_LOCKS
+#define DEBUG_SMB_ENABLE
+#define DEBUG_SMB_LOCKS
 
 #ifdef DEBUG_SMB_ENABLE
 #define DEBUG_SMB(x) g_print x
@@ -746,7 +746,7 @@ build_root_tree (SmbVirtualFile **out)
 
 	if (!get_a_master_browser (&ip)) {
 		g_warning ("Couldn't find a master browser");
-		return GNOME_VFS_ERROR_HOST_NOT_FOUND;
+		return GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE;
 	}
 
 	res = smb_server_connection_new_from_ip (&ip,
@@ -1656,79 +1656,62 @@ open_dir_helper (file_info *info, const char *dir)
 {
 	SmbDirHandle *handle;
 	SmbDirContent *content;
-	GnomeVFSDirectoryFilterNeeds needs;
 	GnomeVFSFileInfo *file_info;
 	gboolean passed;
 
 	handle = g_private_get (dir_key);
 
-	if (handle->filter) {
-		needs = gnome_vfs_directory_filter_get_needs (handle->filter);
-		file_info = gnome_vfs_file_info_new ();
-		
-		if (needs & GNOME_VFS_DIRECTORY_FILTER_NEEDS_NAME) {
-			file_info->name = g_strdup (info->name);
-		}
-			
-		if (needs & GNOME_VFS_DIRECTORY_FILTER_NEEDS_TYPE) {
-			if (content->mode & aDIR) 
-				file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
-			else
-				file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
-			file_info->valid_fields |=
-				GNOME_VFS_FILE_INFO_FIELDS_TYPE;
+	file_info = gnome_vfs_file_info_new ();
 
-		}
-		
-		if (needs & GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE) {
-			if (content->mode & aDIR) 
-				file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
-			else
-				file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
-			file_info->valid_fields |=
-				GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE;
-		}
-		
-		if (needs & GNOME_VFS_DIRECTORY_FILTER_NEEDS_STAT) {
-			if (info->mode & aRONLY)
-				file_info->permissions =
-					GNOME_VFS_PERM_USER_READ | GNOME_VFS_PERM_USER_EXEC |
-					GNOME_VFS_PERM_GROUP_READ | GNOME_VFS_PERM_GROUP_EXEC |
-					GNOME_VFS_PERM_OTHER_READ | GNOME_VFS_PERM_OTHER_EXEC;
-			else
-				file_info->permissions =
-					GNOME_VFS_PERM_USER_ALL |
-					GNOME_VFS_PERM_GROUP_ALL |
-					GNOME_VFS_PERM_OTHER_ALL;
-	
-			file_info->size = info->size;
-			file_info->uid = info->uid;
-			info->gid = info->gid;
-			
-			file_info->mtime = info->mtime;
-			file_info->atime = info->atime;
-			file_info->ctime = info->ctime;
-			
-			file_info->flags = 0;
-			
-			file_info->valid_fields |=
-				GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS |
-				GNOME_VFS_FILE_INFO_FIELDS_FLAGS |
-				GNOME_VFS_FILE_INFO_FIELDS_SIZE |
-				GNOME_VFS_FILE_INFO_FIELDS_ATIME |
-				GNOME_VFS_FILE_INFO_FIELDS_MTIME |
-				GNOME_VFS_FILE_INFO_FIELDS_CTIME;
-		}
+	file_info->name = g_strdup (info->name);
 
-		passed =
-			gnome_vfs_directory_filter_apply (handle->filter,
-							  file_info);
-		gnome_vfs_file_info_unref (file_info);
+	//FIXME this is broken, but otherwise it crashes
+	if (info->mode & aDIR) 
+		file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
+	else
+		file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
+	file_info->valid_fields |=
+		GNOME_VFS_FILE_INFO_FIELDS_TYPE;
+
+	//FIXME same here
+	if (info->mode & aDIR) 
+		file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
+	else
+		file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
+	file_info->valid_fields |=
+		GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE;
+		
+	if (info->mode & aRONLY)
+		file_info->permissions =
+			GNOME_VFS_PERM_USER_READ | GNOME_VFS_PERM_USER_EXEC |
+			GNOME_VFS_PERM_GROUP_READ | GNOME_VFS_PERM_GROUP_EXEC |
+			GNOME_VFS_PERM_OTHER_READ | GNOME_VFS_PERM_OTHER_EXEC;
+	else
+		file_info->permissions =
+			GNOME_VFS_PERM_USER_ALL |
+			GNOME_VFS_PERM_GROUP_ALL |
+			GNOME_VFS_PERM_OTHER_ALL;
+
+	file_info->size = info->size;
+	file_info->uid = info->uid;
+	info->gid = info->gid;
+			
+	file_info->mtime = info->mtime;
+	file_info->atime = info->atime;
+	file_info->ctime = info->ctime;
+			
+	file_info->flags = 0;
+			
+	file_info->valid_fields |=
+		GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS |
+		GNOME_VFS_FILE_INFO_FIELDS_FLAGS |
+		GNOME_VFS_FILE_INFO_FIELDS_SIZE |
+		GNOME_VFS_FILE_INFO_FIELDS_ATIME |
+		GNOME_VFS_FILE_INFO_FIELDS_MTIME |
+		GNOME_VFS_FILE_INFO_FIELDS_CTIME;
+
+	gnome_vfs_file_info_unref (file_info);
 
-		if (!passed)
-			return;
-	}
-	
 	content = g_new (SmbDirContent, 1);
 	content->name = g_strdup (info->name);
 	content->mtime = info->mtime;
@@ -1770,9 +1753,7 @@ do_open_directory (GnomeVFSMethod *method,
 		   GnomeVFSMethodHandle **method_handle,
 		   GnomeVFSURI *uri,
 		   GnomeVFSFileInfoOptions options,
-		   const GnomeVFSDirectoryFilter *filter,
 		   GnomeVFSContext *context)
-
 {
 	GnomeVFSResult res;
 	SmbDirHandle *handle;
@@ -1803,13 +1784,11 @@ do_open_directory (GnomeVFSMethod *method,
 		handle->is_files = FALSE;
 		handle->contents = smb_virtual_file_list_shallow_copy (file->u.directory.dir_contents);
 		handle->server = NULL;
-		handle->filter = filter;
 	} else {
 		handle = g_new (SmbDirHandle, 1);
 		handle->is_files = TRUE;
 		handle->contents = NULL;
 		handle->server = NULL;
-		handle->filter = filter;
 	
 		g_private_set (dir_key, handle);
 
